import torch
import requests
import os
from PIL import Image
import shutil

class Shoes():
    def __init__(self, root_dir='images', download=False, transform=None):
        self.transform = transform
        if download:
            # TODO dont download if it already exists
            zip_dir = f'{root_dir}.zip'
            response = requests.get('https://ai-core-shoes-dataset.s3.eu-west-2.amazonaws.com/data.zip') # download zip file
            with open(zip_dir, 'wb') as f:
                f.write(response.content) # write data to zip file
            shutil.unpack_archive(zip_dir, root_dir) # unzip into root_dir
            os.remove(zip_dir)# remove zip file
        try:
            self.img_fps = [f'{root_dir}/{brand_dir}/{filename}' for brand_dir in os.listdir(root_dir) for filename in os.listdir(f'{root_dir}/{brand_dir}')] # generate image filepaths
        except FileNotFoundError:
            raise FileNotFoundError('You need to download the dataset by using download=True')

    def __len__(self):
        return len(self.img_fps)

    def __getitem__(self, idx):
        fp = self.img_fps[idx]
        label = fp.split('/')[1]
        img = Image.open(fp)
        if self.transform:
            img = self.transform(img)
        return img, label

if __name__ == '__main__':
    import random
    shoes = Shoes(download=False)
    print(len(shoes))
    # img, label = shoes[random.randint(0, len(shoes))]
    # img.show()
    # print(label)


import torch
import requests
import os
import json
from PIL import Image, UnidentifiedImageError
import sys
sys.path.append('../utils')
import create

def download_file(src_url, local_destination):
    response = requests.get(src_url)
    with open(local_destination, 'wb+') as f:
        f.write(response.content)

def create_id_from_url(url):
    id = url.split('/')[-1] # get filename
    id = id.strip('\n') # strip trailing newlines
    id = id.split('?')[0] # remove trailing query string params
    id = id.split('&')[0] # remove trailing query string params
    if len(id.split('.')) == 1: # if no file extension in image id
        id += '.jpg' # guess and add .jpg
    return id

def get_data(idx):
    img_dir = 'images'
    if not os.path.exists(img_dir):
        os.mkdir(img_dir)

    shoe_files = os.listdir('shoes_urls')[idx]
    shoe_files = [shoe_files]
    for file in shoe_files:
        print(file)
        with open(f'shoes_urls/{file}') as f:
            shoes = f.readlines()
        # print(shoes)
        for url in shoes:
            print(url)

            brand_dir = f'{img_dir}/{file.split(".")[0]}'
            if not os.path.exists(brand_dir):
                os.mkdir(brand_dir)

            id = create_id_from_url(url) # TODO replace with uuid

            if 'https://pumaimages.azureedge.net' in url:
                print('skipping shit website')
                continue

            if '.tif' in id:
                print('skipping .tif file')
                continue

            print(id)
            local_dest = f'{brand_dir}/{id}'
            if os.path.exists(local_dest):
                print('image already exists')
                continue
            try:
                download_file(url, local_dest)
            except requests.exceptions.ConnectionError:
                print('failed to get url')
                continue
            except requests.exceptions.TooManyRedirects:
                print('too many redirects')
                continue
            try:
                Image.open(local_dest).close() # open and close to check it works
                print('image opened')
            except UnidentifiedImageError:
                print('img wasnt opened')
                os.remove(local_dest)
                continue
            print()
            # sdfvsd

if __name__ == '__main__':
    # get_data()

    create.zip_up('/Users/ice/shoes', 'images')
    create.s3_upload('ai-core-shoes-dataset', '/Users/ice/shoes.zip')
    

